<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="hr">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vrsta proksija</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP adresa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Korisničko ime</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcionalno</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Spremi</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neispravna IP adresa</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Neispravni port</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Odspoji</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Obriši</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Spremi</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Povezujem se</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Odspoji</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Jeste li sigurni da želite izbrisati ovu konfiguraciju?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Žičana veza %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Bežična veza: %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE veza %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Novi VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Vrsta VPN-a</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>Otvorenaveza</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Izvezi</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OtvoreniVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN otvorena veza %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Pojedinosti mreže</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy sustava</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Žična mreža</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bežična mreža</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Zrakoplovni način</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adapter žične mreže</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Dodaj mrežnu vezu</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adapter bežične mreže</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Povezivanje na skrivenu mrežu</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Napravi PPPoE povezivanje</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN status</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Napravi VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Uvezi VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vrsta proksija</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL podešavanja</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP adresa</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Ulaz</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Korisničko ime</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Sučelje</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Frekvencija</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pristupnik</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primaran DNS</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska podmreže</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Brzina</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Zrakoplovni način</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Neispravna DNS adresa</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Žičana veza</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC adresa uređaja</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Klonirana MAC adresa</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Prilagodi MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Općenito</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Općenito</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Ime već postoji</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Automatsko povezivanje</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Dodaj postavke</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP adresa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pristupnik</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neispravna IP adresa</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska podmreže</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neispravna IP adresa</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatski</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručno</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Zanemari</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP adresa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pristupnik</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Method</source>
        <translation>Način</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska podmreže</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neispravna IP adresa</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP sukob</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Način</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatski</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručno</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Zanemari</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Pojedinosti mreže</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy sustava</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Zrakoplovni način</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Pojedinosti mreže</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP sukob</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Onemogućeno</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručno</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatski</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Korisničko ime</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Usluga</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Odbaci EAP autentifikaciju</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Odbaci PAP autentifikaciju</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Odbaci CHAP autentifikaciju</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Odbaci MSCHAP autentifikaciju</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Odbaci MSCHAPv2 autentifikaciju</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Nema BSD kompresije podataka</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Nema umanjene kompresije podataka</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Nema TCP kompresije zaglavlja</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nema protokola kompresije polja</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nema kompresije Adrese/Kontrole</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Send PPP Echo Packets</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Koristi MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bitni MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stabilni MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Napravi PPPoE povezivanje</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy sustava</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Spremi</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vrsta proksija</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručno</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatski</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcionalno</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP Proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL podešavanja</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Sigurnost</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>BRZO</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunelirani TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Zaštićeni EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Spremi lozinku za ovog korisnika</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Spremi lozinku za sve korisnike</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Uvijek me pitaj</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Onemogućeno</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonimno</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autentificirano</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Oboje</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatski</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Inačica 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Inačica 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP autentifikacija</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identitet</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd opcije</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privatni ključ</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikat</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Korinički certifikat</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anoniman ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Dodjeljivanje</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC datoteka</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Unutarnja autentifikacija</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP inačica</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privatna lozinka</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Neispravna lozinka</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nijedan</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 osobni</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Sigurnost</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ključ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Potrebna sigurnost</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Neispravna lozinka</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nijedan</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 osobni</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Poduzeće</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Sigurnost</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autentifikacija</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ključ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN napredno</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Prilagođeni ulaz pristupnika</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Ulaz pristupnika</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Prilagodi interval ponovnog povezivanja</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Interval ponovnog povezivanja</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Koristite LZO kompresiju podataka</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Koristite TCP spajanje</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Koristite TAP uređaj</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Prilagodi Tunel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Prilagodi UDP veličinu fragmenta</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP veličina fragmenta</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Ograniči Tunel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Naizmjenično odaberi udaljena računala</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN napredno</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (uobičajeno)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Mrežni zaslon</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Osigurano (uobičajeno)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Slabo</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nijedan</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T kada je dostupno (uobičajeno)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T uvijek</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Onemogućeno</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Grupa 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Grupa 2 (uobičajeno)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Grupa 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Poslužitelj (uobičajeno)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Grupa 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domena</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Pružatelj usluge</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Inačica</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Enkripcija</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Grupa</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Unaprijedi sigurnost</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Lokalan ulaz</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Onemogući otkrivanje nedostupnog klijenta</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Omogući IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Naziv grupe</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID grupe</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pred-dijeljeni ključ</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pristupnik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikat</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Dopusti Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD skripta</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Korinički certifikat</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privatni ključ</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Use FSID for Key Passphrase</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certifikati (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certifikati s lozinkom (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Nepromjenjiv ključ</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Spremljeno</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pitaj</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nije potrebno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pristupnik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Vrsta autentifikacije</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikat</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Korinički certifikat</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privatni ključ</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd opcije</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privatna lozinka</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Korisničko ime</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Prilagodi ključ smjera</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key Direction</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Udaljeni IP </translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Lokalna IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Sve dostupno (uobičajeno)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (manje sigurno)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (najsigurnije)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Odbaci EAP autentifikaciju</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Odbaci PAP autentifikaciju</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Odbaci CHAP autentifikaciju</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Odbaci MSCHAP autentifikaciju</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Odbaci MSCHAPv2 autentifikaciju</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Nema BSD kompresije podataka</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Nema umanjene kompresije podataka</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Nema TCP kompresije zaglavlja</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nema protokola kompresije polja</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nema kompresije Adrese/Kontrole</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Send PPP Echo Packets</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Koristi MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sigurnost</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stabilni MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN status</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Napravi VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Uvezi VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Greška uvoza</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nije potrebno</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vrsta proksija</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP poslužitelja</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>U slučaju greške ponavljaj beskonačno puta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Korisničko ime</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA datoteka</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Zanemarite upozorenja certifikata</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN sigurnost</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Uobičajeno</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nijedan</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Šifra</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC autentifikacija</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Spremljeno</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pitaj</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nije potrebno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pristupnik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Korisničko ime</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd opcije</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT domena</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP poslužitelja</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Korisničko ime</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privatni ključ</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pred-dijeljeni ključ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pristupnik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikat</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Vrsta autentifikacije</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Korinički certifikat</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Korisničko ime</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Zatraži lokalnu IP adresu</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Nametni UDP enkapsulaciju</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Koristi IP kompresiju</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS autentifikacija</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Uobičajeno</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klijent</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Poslužitelj</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Podudaranje subjekta</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Vrsta udaljenog certifikata</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Datoteka ključa</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Prilagodi ključ smjera</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key Direction</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Spremljeno</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pitaj</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nije potrebno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pristupnik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Korisničko ime</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd opcije</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Naziv grupe</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Lozinka grupe</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Koristi hibridnu autentičnost</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA datoteka</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Najprije priključite mrežni kabel</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adapter žične mreže</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Dodaj mrežnu vezu</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Odaberi postavke</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adapter bežične mreže</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Povezivanje na skrivenu mrežu</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Potrebno</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC adresa uređaja</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Prilagodi MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>